@@ -1,6 +1,6 @@
 package LaTeX::ToUnicode::Tables;
 BEGIN {
-  $LaTeX::ToUnicode::Tables::VERSION = '0.53';
+  $LaTeX::ToUnicode::Tables::VERSION = '1.93';
 }
 use strict;
 use warnings;
@@ -8,7 +8,12 @@ use warnings;
 
 use utf8; # just for the german support
 
-# Technically not all of these are ligatures, but close enough.
+# The replacement texts throughout this file must not use HTML markup,
+# since any <>& may be converted to entities in the main convert()
+# function in ToUnicode.pm.
+
+
+# TeXnically not all of these are ligatures, but close enough.
 # Order is important, so has to be a list, not a hash.
 # 
 our @LIGATURES = (
@@ -25,36 +30,40 @@ our @LIGATURES = (
 #
 # Some additional ligatures supported in T1 encoding, but we won't (from
 # tex-text.map):
-# U+002C U+002C <> U+201E  ; ,, -> DOUBLE LOW-9 QUOTATION MARK
-# U+003C U+003C <> U+00AB  ; << -> LEFT POINTING GUILLEMET
-# U+003E U+003E <> U+00BB  ; >> -> RIGHT POINTING GUILLEMET
+# ,, -> DOUBLE LOW-9 QUOTATION MARK (U+201E)
+# << -> LEFT POINTING GUILLEMET     (U+00AB)
+# >> -> RIGHT POINTING GUILLEMET    (U+00BB)
 
-#  for {\MARKUP(shape) ...} and \textMARKUP{...}; although not all
-# command names are defined in LaTeX for all markups, we translate them
-# anyway. Also, LaTeX has more font axes not included here: md, ulc, sw,
-# ssc, etc. See ltfntcmd.dtx and ltfssaxes.dtx if we ever want to try
-# for completeness.
+#  for {\MARKUP ...} and {\MARKUPshape ...} and \textMARKUP{...}. Not
+# every combination is defined (e.g., there is no \subscriptshape
+# command), but we convert them all anyway (in convert_markups).
+# 
+# LaTeX has more font axes that are not included here: md, ulc, sw, ssc,
+# etc. See ltfntcmd.dtx and ltfssaxes.dtx if we ever want to try for
+# completeness.
 # 
 our %MARKUPS = (
     'bf'  => 'b',
     'cal' => '',
     'em'  => 'em',
+    'french' => '',  # polyglossia
     'it'  => 'i',
     'rm'  => '',
     'sc'  => '', # qqq should uppercasify
     'sf'  => '',
     'sl'  => 'i',
     'small' => '',
-    'subscript'    => 'sub',
-    'superscript'  => 'sup',
+    'subscript'    => 'sub',  # i.e., \textsubscript
+    'superscript'  => 'sup',  # \textsuperscript
     'tt'  => 'tt',
 );
 
 # More commands taking arguments that we want to handle.
 # 
 our %ARGUMENT_COMMANDS = (
-    'emph'      => ['\textem{', '}'], # \textem doesn't exist, but is processed
+    'emph'      => ['\textem{', '}'], # \textem doesn't exist, but we handle it
     'enquote'   => ["`",        "'"],
+    'natexlab'  => ["",         ""],  # natbib
     'path'      => ['\texttt{', '}'], # ugh, might not be a braced argument
 );
 
@@ -86,10 +95,10 @@ our %CONTROL_SYMBOLS = (
    # = macron accent
     '>'  => '',  # tabbing: next tab stop
    # ? undefined
-    '@'  => '#', # end of sentence
+    '@'  => '', # end of sentence
    # A..Z control words, not symbols
     '['  => '',  # start display math
-    '\\' => ' ', # line break
+    '\\' => ' ', # line break, usually not in HTML
     ']'  => '',  # end display math
    # ^ circumflex accent
     '_'  => '_', # underscore
@@ -114,6 +123,7 @@ our %CONTROL_WORDS_EMPTY = (
     'doi'           => '',
     'egroup'        => '',
     'endgroup'      => '',
+    'ensuremath'    => '',
     'hbox'          => '',
     'ignorespaces'  => '',
     'mbox'          => '',
@@ -123,9 +133,11 @@ our %CONTROL_WORDS_EMPTY = (
     'negthinspace'  => '',
     'newblock'      => '',
     'newpage'       => '',
+    'nobreak'       => '',
     'noindent'      => '',
     'nolinkurl'     => '',
     'oldstylenums'  => '',
+    'par'           => '',
     'pagebreak'     => '',
     'protect'       => '',
     'raggedright'   => '',
@@ -148,25 +160,37 @@ our %CONTROL_WORDS = (
     'MF'             => 'Metafont',
     'MP'             => 'MetaPost',
     'Omega'          => '\x{03A9}',
+    'P'              => '\x{00B6}',
+    'S'              => '\x{00A7}',
     'TeX'            => 'TeX',
     'XeLaTeX'        => 'XeLaTeX',
     'XeTeX'          => 'XeTeX',
+    'allowbreak'     => '\x{200B}', # zero width space to allow breaks
+    'ast'            => '*',
     'bullet'         => '\x{2022}',
     'dag'            => '\x{2020}',
+    'dagger'         => '\x{2020}',
     'ddag'           => '\x{2021}',
+    'ddagger'        => '\x{2021}',
     'dots'           => '\x{2026}',
     'epsilon'        => '\x{03F5}',
-    'hookrightarrow' => '\x{2194}',
+    'guillemetleft'  => '\x{00AB}',
+    'guillemetright' => '\x{00BB}',
+    'hookleftarrow'  => '\x{21A9}',
+    'hookrightarrow' => '\x{21AA}',
     'ldots'          => '\x{2026}',
     'log'            => 'log',
     'omega'          => '\x{03C9}',
     'par'            => "\n\n",
+    'parallel'       => '\x{2016}',
     'qquad'          => ' ', # 2em space
     'quad'           => ' ', # em space
     'textbackslash'  => '\x{005C}', # entities so \ in output indicates
                                     # untranslated TeX source
     'textbraceleft'  => '\x{007B}', # entities so our bare-brace removal
     'textbraceright' => '\x{007D}', # skips them
+    'textdagger'     => '\x{2020}',
+    'textddagger'    => '\x{2020}',
     'textgreater'    => '\x{003E}',
     'textless'       => '\x{003C}',
     'textquotedbl'   => '"',
@@ -200,6 +224,7 @@ our %SYMBOLS = ( # Table 3.2 in Lamport, plus more
     'TH' => '\x{00DE}', # THORN
     'textordfeminine'  => '\x{00AA}',
     'textordmasculine' => '\x{00BA}',
+    "textquotesingle"  => '\x{0027}',
     'textregistered'   => '\x{00AE}',
     'th' => '\x{00FE}',
     'TM' => '\x{2122}', # trade mark sign
@@ -601,7 +626,7 @@ our %GERMAN = ( # for package `german'/`ngerman'
     "\"'"   => '“',
     '"<'    => '«',
     '">'    => '»',
-    '"-'    => '\x{AD}',    # soft hyphen
+    '"-'    => '\x{00AD}',    # soft hyphen
     '""'    => '\x{200B}',  # zero width space
     '"~'    => '\x{2011}',  # non-breaking hyphen
     '"='    => '-',
@@ -625,7 +650,7 @@ LaTeX::ToUnicode::Tables - Character tables for LaTeX::ToUnicode
 
 =head1 VERSION
 
-version 0.53
+version 0.54
 
 =head1 CONSTANTS
 
@@ -663,7 +688,7 @@ A hash where the keys are non-alphabetic C<\command>s (without the
 backslash), other than accents and special cases. These don't take
 arguments. Although some of these have Unicode equivalents, such as the
 C<\,> thin space, it seems better to keep the output as simple as
-possible; spacing tweaks in the TeX aren't usually desirable in plain
+possible; small spacing tweaks in TeX aren't usually desirable in plain
 text or HTML.
 
 The values are single-quoted strings C<'\x{...}'>, not double-quoted
@@ -717,7 +742,7 @@ L<https://github.com/borisveytsman/bibtexperllibs>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2010-2023 Gerhard Gossen, Boris Veytsman, Karl Berry
+Copyright 2010-2025 Gerhard Gossen, Boris Veytsman, Karl Berry
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl5 programming language system itself.
